import { Avatar, Card, CardContent, Tooltip, Typography } from "@mui/material";
import { decodeTime } from "ulid";
import { DateTime } from "luxon";

import type { Post } from "$lib/api/entities/post";
import humanizeDuration from "$/lib/duration";

import "./Post.css";
import { renderMarkdown } from "$/lib/markdown";

interface Props {
	post: Post;
}

export default function Post(props: Props) {
	return (
		<Card>
			<CardContent>
				<div className="post-Post--account">
					<Avatar sx={{ width: 48, height: 48 }}>
						{props.post.blog.name.slice(0, 1).toUpperCase()}
					</Avatar>
					<div className="post-Post--names">
						<Typography>{props.post.blog.name}</Typography>
						<Typography color="grey">@{props.post.blog.name}</Typography>
					</div>
					<Timestamp timestamp={decodeTime(props.post.id)} />
				</div>
				<PostContent post={props.post} />
			</CardContent>
		</Card>
	);
}

function Timestamp({ timestamp }: { timestamp: number }) {
	const msAgo = new Date().getTime() - timestamp;
	const timeString = DateTime.fromMillis(timestamp).toLocaleString(
		DateTime.DATETIME_SHORT,
	);

	return (
		<>
			<Tooltip title={timeString}>
				<Typography variant="subtitle2">{humanizeDuration(msAgo)}</Typography>
			</Tooltip>
		</>
	);
}

function PostContent({ post, small = true }: { post: Post; small?: boolean }) {
	return (
		<>
			<Typography variant={small ? "body2" : "body1"}>
				<p dangerouslySetInnerHTML={{ __html: renderMarkdown(post.content) }} />
			</Typography>
		</>
	);
}
